All Classes and Interfaces

Class
Description
 
 
Producer endpoint that closes a pull request.
 
Producer endpoint that creates an issue.
 
Producer endpoint that gets the file associated with a CommitFile object.
Deprecated.
since 4.18, use
invalid reference
org.apache.camel.component.github2.GitHub2Component
(camel-github2) instead
Generated by camel build tools - do NOT edit this file!
 
Deprecated.
since 4.18, use
invalid reference
org.apache.camel.component.github2.GitHub2Endpoint
(camel-github2) instead
Generated by camel build tools - do NOT edit this file!
Generated by camel build tools - do NOT edit this file!
An abstraction that allows customization of how the EventsConsumer fetches GitHub events.
 
 
Producer endpoint that adds one of two types of comments on a GitHub pull request: 1.)
 
Producer endpoint that gets the files associated with a pull request.
Producer endpoint that sets the commit status.